# Minimal setup


from setuptools import setup

setup(name='cbipy',
      version='0.1',
      description='My little application',
      url='http://github.com/kip-marks/cbipy',
      author='Kip Marks',
      author_email='kip.marks@gmail.com',
      license='MIT',
      packages=['cbipy'],
      zip_safe=False)

